<?php
/*
Plugin Name: Custom Meta Widget
Plugin URI: http://shinraholdings.com/plugins/custom-meta-widget
Description: Clone of the standard Meta widget with options to hide thlogin, admin, entry and comment feed, WordPress.org and /custom links.
Version: 1.4.1
Author: bitacre
Author URI: http://shinraholdings.com/
License: GPLv2
	Copyright 2012 Shinra Web Holdings (http://shinraholdings.com)
*/

class customMetaWidget extends WP_Widget {

// constructor
function customMetaWidget() { 
	// set widget options
	$widget_ops = array ( 
		'classname' => 'customMetaWidget',
		'description' => __( 'Hide the individual log in/out, admin, feed and WordPress links', 'customMetaWidget' )
	); 
	// extend class
	$this->WP_Widget( 'customMetaWidget', 'Custom Meta', $widget_ops );
}

// declare form options (not part of WP_Widget)
function get_options() {
	$options = array ( 
		'title' => array( 
			'slug' => 'title', 
			'type' => 'text', 
			'default' => __( 'Meta', 'customMetaWidget' ), 
			'label' => __( 'Title', 'customMetaWidget' ),
			'before' => '' ),
			
		'register' => array(
			'slug' => 'register', 
			'type' => 'checkbox', 
			'default' => 1,
			'label' => __( 'Show "Register/Admin" link?', 'customMetaWidget' ), 
			'before' => '' ),
			
		'login' => array(
			'slug' => 'login', 
			'type' => 'checkbox', 
			'default' => 1,
			'label' => __( 'Show "Log in/out" link?', 'customMetaWidget' ),
			'before' => '' ),
			
		'entryrss' => array(
			'slug' => 'entryrss',
			'type' => 'checkbox',
			'default' => 1,
			'label' => __( 'Show "Entries RSS" link?', 'customMetaWidget' ), 
			'before' => '' ), 
			
		'commentrss' => array( 
			'slug' => 'commentrss',
			'type' => 'checkbox', 
			'default' => 1,
			'label' => __( 'Show "Comments RSS" link?', 'customMetaWidget' ),
			'before' => '' ),
			
		'wordpress' => array(
			'slug' => 'wordpress',
			'type' => 'checkbox',
			'default' => 1,
			'label' => __( 'Show "WordPress.org" link?', 'customMetaWidget' ), 
			'before' => '' ), 
		'showcustom' => array( 
			'slug' => 'showcustom', 
			'type' => 'checkbox', 
			'default' => 0,
			'label' => __( 'Show the custom link?', 'customMetaWidget' ), 
			'before' => '' ), 
		'customurl' => array(
			'slug' => 'customurl',
			'type' => 'text',
			'default' => '',
			'label' => __( 'URL', 'customMetaWidget' ),
			'before' => ' style="margin-left:20px;"' ),
			
		'customtext' => array(
			'slug' => 'customtext',
			'type' => 'text',
			'default' => '',
			'label' => __( 'Text', 'customMetaWidget' ),
			'before' => ' style="margin-left:20px;"' ),
			
		'linklove' => array(
			'slug' => 'linklove',
			'type' => 'checkbox',
			'default' => 0,
			'label' => __( 'Show Plugin link?', 'customMetaWidget' ),
			'before' => '' ) 
	);

	return $options;
}

// draw widget options
function form( $instance ) { 
	$options = $this->get_options();
	
	// get defaults array
	$defaults = array();
	foreach( $options as $key=>$value )
		$defaults = array_merge( $defaults, array( $key => $value['default'] ) );

	// parse instance values over defaults
	$instance = wp_parse_args( ( array ) $instance, $defaults ); 

	// loop through text boxes
	foreach( $options as $slug=>$value ) {
		
		if( $value['type'] == 'text' ) 
			printf( '<!-- %1$s -->
	<p%6$s>
		<label for="%2$s">%3$s: </label>
		<input class="widefat" id="%4$s" name="%2$s" type="text" value="%5$s" />
	</p>',
			$slug,
			$this->get_field_name( $slug ),
			$value['label'],
			$this->get_field_id( $slug ),
			esc_attr( $instance[$slug] ),
			$value['before']
		);
	
		elseif( $value['type'] == 'checkbox' )
			printf( '<!-- %1$s -->
	<p%6$s>
		<label for="%2$s">%3$s</label>
		<input id="%4$s" name="%2$s" type="checkbox" value="1" %5$s />
	</p>',
			$slug,
			$this->get_field_name( $slug ),
			$value['label'],
			$this->get_field_id( $slug ),
			checked( $instance[$slug], 1, false ),
			$value['before']
		);
	}

echo '<small>(' . __( 'An awesome way to support this free plugin!', 'customMetaWidget' ) . ')</small></p>';

	 // check for errors
	if ( esc_attr( $instance['showcustom'] ) ) { // IF 'showcustom' is checked, AND
			
			// 1. no link and no URL
			if( empty( $instance['customtext']) && empty($instance['customurl'] ) ) 
				echo '<p style="color:#f00; font-weight:bold;" >' . __( 'You have a custom link with no URL or text!', 'customMetaWidget' ) . '</p>';
			// 2. no link
			elseif( empty( $instance['customtext'] ) ) 
				echo '<p style="color:#f00; font-weight:bold;" >' . __( 'You have a custom link with no text!', 'customMetaWidget' ) . '</p>';
			
			// 3. no url
			elseif( empty($instance['customurl' ]) )
				echo '<p style="color:#f00; font-weight:bold;" >' . __( 'You have a custom link with no URL!', 'customMetaWidget' ) . '</p>';
	}
}

// SAVE WIDGET OPTIONS
function update( $new_instance, $old_instance) {
	$instance = $old_instance;
	$options = $this->get_options();
	
	foreach( $options as $key=>$value )
		$instance[$key] = $new_instance[$key];

	return $instance;
}

// ACTUAL WIDGET OUTPUT
function widget( $args, $instance ) { 
   	extract( $args, EXTR_SKIP ); // extract arguments
	$title = empty( $instance['title'] ) ? __( 'Meta', 'customMetaWidget' ) : apply_filters( 'widget_title', $instance['title'] ); // if no title, use default

	// insert start of widget HTML comment
	echo '
<!-- 
' . __( 'Plugin: Custom Meta Widget', 'customMetaWidget' ) . '
' . __( 'Plugin URL', 'customMetaWidget' ) . ': http://shinraholdings.com/plugins/custom-meta-widget
-->
';

	echo $before_widget; // insert pre-widget code (from theme)
	echo $before_title . esc_attr( $instance['title'] ) . $after_title; // echo title (inside theme tags)
	echo '<ul>' . "\r\n"; 
	
	// ADD LINKS
	if( esc_attr( $instance['register'] ) ) wp_register( '<li>', '</li>' ); // 1. register link
	
	if( esc_attr( $instance['login'] ) ) echo '<li>' . wp_loginout( NULL, FALSE ) . '</li>'; // 2. login link
	
	if( esc_attr( $instance['entryrss'] ) ) // 3. entries RSS link
		printf( __( '%1$sSyndicate this site using RSS 2.0%2$sEntries %3$sRSS%4$s', 'customMetaWidget' ), 
		'<li><a href="' . get_bloginfo( 'rss2_url' ) . '" title="', '">',
		'<abbr title="' . __( 'Really Simple Syndication', 'customMetaWidget' ) . '">',
		'</abbr></a></li>' ); // 4. comments RSS link
	
	if( esc_attr( $instance['commentrss'] ) ) 
		printf( __( '%1$sSyndicate this site using RSS 2.0%2$sComments %3$sRSS%4$s', 'customMetaWidget' ),
		'<li><a href="' . get_bloginfo( 'comments_rss2_url' ) . '" title="', '">',
		'<abbr title="' . __( 'Really Simple Syndication', 'customMetaWidget' ) . '">',
		'</abbr></a></li>' );// 4. entires RSS link
		
	if( esc_attr( $instance['wordpress'] ) ) echo '<li><a href="http://wordpress.org/" title="' . __( 'Powered by WordPress, state-of-the-art semantic personal publishing platform.', 'customMetaWidget' ) . '">WordPress.org</a></li>'; // 5. wordpress.org link
	
	if( esc_attr( $instance['showcustom'] ) ) { // 6. custom link
		if( !empty( $instance['customtext'] ) 
		&& !empty( $instance['customurl'] ) ) 
			echo '<li><a href="' . esc_attr( $instance['customurl'] ) . '">' . esc_attr( $instance['customtext'] ) . '</a></li>';
		// otherwise insert error comment
		else 
			echo '
<!-- ' . __( 'Error: "Show Custom Link" is checked, but either the text or URL for that link are not specified. The link was not displayed because it would be broken. Check the settings for your Custom Meta widget.', 'customMetaWidget' ) . ' -->
'; 
	}

	if( esc_attr( $instance['linklove'] ) ) { // 7. link love
		echo '<li><a href="http://shinraholdings.com/plugins/custom-meta-widget" title="' . __( 'WordPress Plugin Homepage', 'customMetaWidget' ) . '">' . __( 'Custom Meta', 'customMetaWidget' ) . '</a></li>';
	}
	
	echo "\r\n" . '</ul>';
	echo $after_widget; 
}
// end class
}

// ADD HOOKS AND FILTERS
add_action( 'widgets_init', create_function('', 'unregister_widget( "WP_Widget_Meta" ); register_widget("customMetaWidget" );' ) );
add_action( 'plugins_loaded', create_function( '', 'load_plugin_textdomain( "customMetaWidget", null,  trailingslashit( basename(dirname(__FILE__) ) ) . "lang" );' ) );
?>